@@ -200,6 +200,7 @@ L<perl>,
 L<CheckDigits>,
 F<www.pruefziffernberechnung.de>,
 F<www.export911.com/e911/coding/upcChar.htm>,
-F<www.adams1.com/pub/russadam/upccode.html>.
+F<www.adams1.com/pub/russadam/upccode.html>,
+F<http://www.upcdatabase.com>.
 
 =cut
